Learn R Programming

RegularizedSCA (version 0.5.0)

mySTD: Standardize the given data matrix per column, over the rows.

Description

Standardize the given data matrix per column, over the rows.

Usage

mySTD(DATA)

Arguments

DATA

A data matrix

Value

a standardized matrix

Examples

Run this code
# NOT RUN {
mySTD(matrix(1:12, nrow = 3, ncol = 4))
# }

Run the code above in your browser using DataLab